@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE DataKinds, PolyKinds, TypeFamilies, GADTs, ConstraintKinds, TypeOperators #-}
 
 module T12919 where
@@ -13,7 +12,8 @@ data V :: N -> Type where
 type family VC (n :: N) :: Type where
   VC Z = Type
 
-type family VF (xs :: V n) (f :: VC n) :: Type where
+type VF :: V n -> VC n -> Type
+type family VF xs f where
   VF VZ f = f
 
 data Dict c where
